pub enum ExtensionQueryMsg {
Keeper(KeeperQueryMsg),
Lockup(LockupQueryMsg),
}Expand description
Contains QueryMsgs of all enabled extensions. To enable extensions defined
outside of this crate, you can define your own ExtensionQueryMsg type
in your contract crate and pass it in as the generic parameter to QueryMsg
Variants
Keeper(KeeperQueryMsg)
Available on crate feature
keeper only.Lockup(LockupQueryMsg)
Available on crate feature
lockup only.Trait Implementations
Sourceimpl Clone for ExtensionQueryMsg
impl Clone for ExtensionQueryMsg
Sourcefn clone(&self) -> ExtensionQueryMsg
fn clone(&self) -> ExtensionQueryMsg
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtensionQueryMsg
impl Debug for ExtensionQueryMsg
Sourceimpl<'de> Deserialize<'de> for ExtensionQueryMsg
impl<'de> Deserialize<'de> for ExtensionQueryMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtensionQueryMsg
impl JsonSchema for ExtensionQueryMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtensionQueryMsg
impl PartialEq for ExtensionQueryMsg
Sourceimpl Serialize for ExtensionQueryMsg
impl Serialize for ExtensionQueryMsg
impl StructuralPartialEq for ExtensionQueryMsg